# Propagating Business Context Relations to Parent Applications (Relation Inheritance)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#prerequisites)
  * [Automation Logic](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#automation-logic)
  * [How It Works: Example](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#how-it-works:-example)
  * [Technical Details](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#technical-details)
  * [Configuration](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#configuration)
  * [Automation 1: Relation Is Added (Business Context to Child)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#automation-1:-relation-is-added-\(business-context-to-child\))
  * [Automation 2: Relation Is Removed (Business Context from Child)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance#automation-2:-relation-is-removed-\(business-context-from-child\))


View all
Configure automations with scripts to automatically propagate relations from business contexts to parent applications.
